#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.na"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[2069]; const double alignment; void * const ptr;}  na_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0010, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0004, 0000, 0000, 0000, 0004, 0000, 0000, 0000, 
  0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0010, 0000, 0000, 0000, 0010, 0000, 0000, 0000, 
  0000, 0113, 0055, 0223, 0002, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0010, 0001, 0000, 0000, 0014, 0001, 0000, 0000, 0350, 0136, 0053, 0125, 0005, 0000, 0000, 0000, 
  0014, 0001, 0000, 0000, 0047, 0000, 0166, 0000, 0070, 0001, 0000, 0000, 0104, 0007, 0000, 0000, 
  0201, 0321, 0040, 0031, 0004, 0000, 0000, 0000, 0104, 0007, 0000, 0000, 0005, 0000, 0114, 0000, 
  0114, 0007, 0000, 0000, 0120, 0007, 0000, 0000, 0341, 0367, 0354, 0015, 0005, 0000, 0000, 0000, 
  0120, 0007, 0000, 0000, 0032, 0000, 0166, 0000, 0160, 0007, 0000, 0000, 0352, 0007, 0000, 0000, 
  0113, 0120, 0220, 0013, 0006, 0000, 0000, 0000, 0352, 0007, 0000, 0000, 0004, 0000, 0114, 0000, 
  0360, 0007, 0000, 0000, 0364, 0007, 0000, 0000, 0063, 0005, 0100, 0241, 0007, 0000, 0000, 0000, 
  0364, 0007, 0000, 0000, 0003, 0000, 0114, 0000, 0370, 0007, 0000, 0000, 0000, 0010, 0000, 0000, 
  0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 0000, 0010, 0000, 0000, 0001, 0000, 0114, 0000, 
  0004, 0010, 0000, 0000, 0010, 0010, 0000, 0000, 0265, 0144, 0045, 0040, 0000, 0000, 0000, 0000, 
  0010, 0010, 0000, 0000, 0007, 0000, 0114, 0000, 0020, 0010, 0000, 0000, 0024, 0010, 0000, 0000, 
  0160, 0141, 0156, 0145, 0154, 0057, 0000, 0000, 0007, 0000, 0000, 0000, 0156, 0157, 0164, 0151, 
  0146, 0151, 0143, 0141, 0164, 0151, 0157, 0156, 0055, 0141, 0162, 0145, 0141, 0055, 0160, 0162, 
  0145, 0146, 0145, 0162, 0145, 0156, 0143, 0145, 0163, 0055, 0144, 0151, 0141, 0154, 0157, 0147, 
  0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 0336, 0034, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0325, 0131, 0155, 0163, 0233, 0070, 0020, 0376, 0316, 0257, 0330, 0343, 0123, 0073, 
  0027, 0342, 0330, 0235, 0266, 0067, 0115, 0342, 0216, 0233, 0326, 0251, 0147, 0222, 0064, 0023, 
  0073, 0323, 0311, 0047, 0106, 0200, 0000, 0065, 0102, 0342, 0044, 0141, 0307, 0367, 0353, 0157, 
  0001, 0307, 0057, 0005, 0233, 0340, 0346, 0332, 0353, 0247, 0140, 0330, 0147, 0265, 0373, 0150, 
  0337, 0244, 0234, 0274, 0177, 0110, 0070, 0114, 0251, 0322, 0114, 0212, 0123, 0273, 0173, 0170, 
  0144, 0003, 0025, 0276, 0014, 0230, 0210, 0116, 0355, 0333, 0311, 0320, 0371, 0313, 0176, 0337, 
  0267, 0116, 0376, 0160, 0034, 0070, 0247, 0202, 0052, 0142, 0150, 0000, 0063, 0146, 0142, 0210, 
  0070, 0011, 0050, 0274, 0072, 0354, 0365, 0016, 0273, 0140, 0131, 0011, 0176, 0161, 0122, 0042, 
  0050, 0007, 0007, 0212, 0277, 0116, 0252, 0144, 0112, 0225, 0141, 0124, 0073, 0001, 0043, 0134, 
  0106, 0326, 0231, 0114, 0347, 0212, 0105, 0261, 0201, 0027, 0147, 0057, 0341, 0022, 0041, 0360, 
  0221, 0116, 0051, 0317, 0345, 0054, 0153, 0022, 0063, 0015, 0010, 0212, 0024, 0111, 0000, 0037, 
  0103, 0105, 0051, 0150, 0031, 0232, 0031, 0121, 0364, 0030, 0346, 0062, 0003, 0237, 0010, 0120, 
  0064, 0140, 0332, 0050, 0346, 0145, 0010, 0147, 0006, 0210, 0010, 0072, 0122, 0131, 0011, 0032, 
  0035, 0316, 0363, 0027, 0231, 0010, 0250, 0002, 0023, 0123, 0060, 0124, 0045, 0032, 0144, 0130, 
  0374, 0070, 0277, 0272, 0135, 0370, 0300, 0341, 0072, 0363, 0070, 0363, 0341, 0202, 0371, 0124, 
  0150, 0152, 0021, 0134, 0067, 0177, 0243, 0143, 0364, 0316, 0233, 0027, 0342, 0303, 0174, 0365, 
  0361, 0142, 0165, 0030, 0112, 0324, 0112, 0014, 0262, 0164, 0014, 0024, 0335, 0307, 0005, 0026, 
  0254, 0101, 0317, 0132, 0054, 0260, 0320, 0166, 0000, 0122, 0301, 0013, 0142, 0162, 0203, 0025, 
  0310, 0064, 0007, 0275, 0104, 0053, 0347, 0300, 0321, 0341, 0045, 0356, 0260, 0352, 0360, 0312, 
  0257, 0000, 0230, 0050, 0164, 0306, 0110, 0015, 0076, 0240, 0066, 0164, 0154, 0306, 0070, 0007, 
  0217, 0102, 0246, 0151, 0230, 0361, 0003, 0013, 0045, 0341, 0353, 0150, 0362, 0371, 0313, 0355, 
  0004, 0006, 0127, 0167, 0360, 0165, 0160, 0163, 0063, 0270, 0232, 0334, 0035, 0027, 0073, 0044, 
  0361, 0053, 0222, 0133, 0352, 0141, 0111, 0312, 0131, 0276, 0165, 0104, 0051, 0042, 0314, 0034, 
  0111, 0261, 0056, 0077, 0335, 0234, 0175, 0106, 0371, 0301, 0207, 0321, 0305, 0150, 0162, 0227, 
  0233, 0075, 0034, 0115, 0256, 0076, 0215, 0307, 0060, 0374, 0162, 0003, 0003, 0270, 0036, 0334, 
  0114, 0106, 0147, 0267, 0027, 0203, 0033, 0270, 0276, 0275, 0271, 0376, 0062, 0376, 0164, 0010, 
  0060, 0246, 0271, 0101, 0324, 0332, 0116, 0047, 0204, 0250, 0051, 0221, 0310, 0132, 0100, 0015, 
  0141, 0134, 0243, 0253, 0167, 0270, 0171, 0032, 0115, 0342, 0001, 0304, 0144, 0112, 0161, 0023, 
  0175, 0312, 0246, 0150, 0020, 0001, 0037, 0203, 0342, 0051, 0173, 0304, 0245, 0210, 0312, 0320, 
  0063, 0153, 0274, 0035, 0003, 0013, 0101, 0110, 0163, 0000, 0063, 0305, 0060, 0040, 0214, 0254, 
  0356, 0236, 0265, 0332, 0275, 0003, 0030, 0011, 0377, 0360, 0000, 0136, 0167, 0121, 0204, 0210, 
  0173, 0216, 0074, 0217, 0015, 0012, 0243, 0202, 0041, 0013, 0121, 0371, 0220, 0113, 0251, 0016, 
  0340, 0203, 0324, 0046, 0027, 0277, 0034, 0000, 0034, 0365, 0272, 0335, 0043, 0247, 0373, 0352, 
  0250, 0173, 0000, 0267, 0343, 0001, 0272, 0063, 0310, 0220, 0137, 0365, 0016, 0276, 0112, 0036, 
  0106, 0004, 0355, 0272, 0345, 0236, 0142, 0176, 0154, 0131, 0216, 0203, 0351, 0302, 0004, 0156, 
  0164, 0110, 0174, 0332, 0267, 0000, 0116, 0024, 0375, 0073, 0143, 0212, 0152, 0340, 0314, 0073, 
  0265, 0043, 0163, 0377, 0247, 0275, 0112, 0271, 0074, 0201, 0354, 0116, 0041, 0227, 0047, 0331, 
  0022, 0351, 0360, 0322, 0157, 0307, 0314, 0061, 0002, 0242, 0224, 0117, 0173, 0220, 0353, 0256, 
  0310, 0011, 0222, 0120, 0130, 0317, 0276, 0072, 0241, 0200, 0152, 0137, 0261, 0042, 0024, 0267, 
  0045, 0147, 0075, 0320, 0137, 0146, 0354, 0146, 0266, 0326, 0113, 0223, 0202, 0026, 0135, 0241, 
  0345, 0121, 0132, 0172, 0337, 0250, 0157, 0300, 0347, 0104, 0353, 0123, 0373, 0334, 0334, 0017, 
  0202, 0157, 0231, 0066, 0011, 0025, 0306, 0006, 0026, 0234, 0332, 0144, 0371, 0273, 0153, 0347, 
  0010, 0304, 0054, 0014, 0235, 0103, 0356, 0350, 0251, 0315, 0345, 0214, 0052, 0273, 0377, 0366, 
  0244, 0363, 0370, 0241, 0136, 0056, 0113, 0323, 0134, 0256, 0173, 0164, 0324, 0044, 0071, 0045, 
  0074, 0243, 0166, 0277, 0367, 0246, 0111, 0120, 0033, 0232, 0272, 0114, 0370, 0212, 0026, 0006, 
  0367, 0273, 0115, 0200, 0224, 0104, 0164, 0007, 0340, 0244, 0123, 0362, 0121, 0117, 0315, 0050, 
  0101, 0164, 0311, 0012, 0313, 0037, 0267, 0021, 0062, 0145, 0232, 0171, 0034, 0035, 0230, 0250, 
  0214, 0066, 0131, 0204, 0365, 0323, 0015, 0245, 0237, 0151, 0273, 0077, 0044, 0134, 0067, 0312, 
  0063, 0137, 0012, 0067, 0177, 0264, 0373, 0063, 0046, 0002, 0071, 0163, 0174, 0056, 0277, 0207, 
  0355, 0366, 0343, 0143, 0021, 0135, 0245, 0043, 0230, 0247, 0054, 0144, 0176, 0221, 0211, 0056, 
  0046, 0046, 0161, 0123, 0105, 0103, 0252, 0260, 0345, 0120, 0355, 0226, 0161, 0150, 0077, 0217, 
  0345, 0236, 0124, 0330, 0005, 0334, 0031, 0013, 0114, 0154, 0367, 0137, 0067, 0211, 0033, 0146, 
  0220, 0103, 0060, 0130, 0023, 0064, 0226, 0151, 0202, 0214, 0236, 0332, 0163, 0212, 0253, 0135, 
  0255, 0331, 0014, 0003, 0264, 0031, 0256, 0127, 0066, 0067, 0251, 0305, 0254, 0147, 0377, 0220, 
  0142, 0173, 0236, 0144, 0165, 0111, 0262, 0233, 0112, 0315, 0362, 0365, 0354, 0076, 0326, 0000, 
  0114, 0256, 0106, 0353, 0261, 0106, 0270, 0061, 0313, 0143, 0254, 0044, 0261, 0002, 0360, 0143, 
  0306, 0203, 0362, 0071, 0207, 0163, 0314, 0326, 0130, 0162, 0144, 0250, 0263, 0020, 0350, 0254, 
  0111, 0224, 0322, 0145, 0136, 0013, 0302, 0235, 0342, 0047, 0106, 0232, 0047, 0037, 0354, 0245, 
  0216, 0312, 0106, 0177, 0300, 0257, 0305, 0056, 0227, 0046, 0070, 0033, 0342, 0055, 0343, 0166, 
  0237, 0010, 0250, 0303, 0110, 0305, 0220, 0100, 0122, 0162, 0071, 0315, 0353, 0235, 0117, 0370, 
  0123, 0200, 0072, 0045, 0076, 0316, 0100, 0130, 0026, 0152, 0245, 0353, 0011, 0042, 0376, 0062, 
  0260, 0327, 0034, 0257, 0345, 0052, 0063, 0330, 0135, 0276, 0147, 0154, 0033, 0176, 0017, 0362, 
  0366, 0045, 0260, 0032, 0054, 0115, 0116, 0224, 0036, 0024, 0145, 0301, 0053, 0137, 0174, 0217, 
  0254, 0051, 0342, 0304, 0243, 0274, 0066, 0333, 0334, 0263, 0152, 0175, 0331, 0255, 0353, 0111, 
  0124, 0064, 0320, 0321, 0026, 0032, 0023, 0275, 0057, 0064, 0137, 0065, 0240, 0041, 0311, 0270, 
  0151, 0017, 0136, 0114, 0115, 0172, 0245, 0141, 0347, 0106, 0326, 0126, 0364, 0242, 0255, 0364, 
  0313, 0226, 0322, 0006, 0210, 0103, 0247, 0133, 0114, 0326, 0070, 0062, 0065, 0262, 0275, 0336, 
  0022, 0066, 0225, 0022, 0377, 0036, 0363, 0252, 0171, 0071, 0372, 0200, 0163, 0112, 0260, 0207, 
  0203, 0041, 0016, 0311, 0173, 0300, 0126, 0045, 0267, 0273, 0313, 0255, 0132, 0373, 0067, 0212, 
  0347, 0166, 0002, 0352, 0235, 0337, 0313, 0361, 0075, 0234, 0256, 0016, 0047, 0376, 0275, 0233, 
  0067, 0016, 0273, 0117, 0105, 0360, 0144, 0324, 0222, 0246, 0243, 0172, 0110, 0015, 0105, 0025, 
  0172, 0252, 0005, 0246, 0132, 0134, 0260, 0355, 0122, 0117, 0312, 0373, 0345, 0340, 0120, 0376, 
  0372, 0157, 0313, 0142, 0033, 0130, 0303, 0200, 0261, 0265, 0261, 0304, 0330, 0337, 0261, 0342, 
  0351, 0226, 0333, 0125, 0340, 0312, 0065, 0237, 0251, 0174, 0237, 0053, 0026, 0224, 0354, 0106, 
  0345, 0211, 0313, 0215, 0362, 0067, 0077, 0247, 0342, 0266, 0316, 0317, 0204, 0250, 0210, 0011, 
  0227, 0323, 0020, 0253, 0336, 0233, 0075, 0220, 0305, 0051, 0146, 0077, 0250, 0221, 0351, 0176, 
  0100, 0117, 0142, 0103, 0114, 0132, 0142, 0025, 0156, 0364, 0162, 0374, 0150, 0205, 0364, 0045, 
  0317, 0022, 0261, 0002, 0167, 0173, 0073, 0321, 0265, 0161, 0122, 0037, 0053, 0027, 0145, 0303, 
  0316, 0203, 0045, 0101, 0277, 0212, 0143, 0001, 0116, 0266, 0324, 0055, 0073, 0171, 0235, 0222, 
  0037, 0210, 0233, 0037, 0215, 0235, 0372, 0226, 0315, 0131, 0204, 0145, 0113, 0033, 0242, 0114, 
  0133, 0360, 0216, 0171, 0345, 0222, 0011, 0226, 0144, 0011, 0214, 0220, 0022, 0030, 0043, 0045, 
  0357, 0332, 0052, 0157, 0325, 0130, 0267, 0204, 0233, 0240, 0211, 0024, 0314, 0317, 0253, 0121, 
  0104, 0061, 0312, 0067, 0067, 0111, 0247, 0114, 0354, 0126, 0271, 0255, 0137, 0357, 0356, 0331, 
  0265, 0124, 0141, 0202, 0272, 0304, 0030, 0342, 0307, 0133, 0173, 0304, 0166, 0064, 0146, 0332, 
  0123, 0301, 0133, 0172, 0361, 0226, 0176, 0334, 0076, 0344, 0307, 0110, 0332, 0372, 0204, 0133, 
  0245, 0364, 0047, 0207, 0375, 0076, 0360, 0370, 0161, 0232, 0330, 0007, 0154, 0350, 0203, 0251, 
  0015, 0372, 0336, 0233, 0266, 0252, 0126, 0367, 0072, 0166, 0177, 0355, 0216, 0247, 0065, 0033, 
  0234, 0045, 0236, 0233, 0137, 0102, 0357, 0034, 0323, 0352, 0301, 0042, 0113, 0250, 0142, 0376, 
  0176, 0134, 0154, 0275, 0044, 0372, 0051, 0171, 0324, 0375, 0215, 0363, 0150, 0167, 0353, 0160, 
  0123, 0366, 0100, 0271, 0376, 0035, 0072, 0310, 0366, 0046, 0120, 0372, 0360, 0113, 0042, 0243, 
  0367, 0277, 0212, 0214, 0172, 0047, 0153, 0205, 0027, 0127, 0050, 0371, 0001, 0004, 0215, 0042, 
  0236, 0135, 0075, 0052, 0126, 0056, 0251, 0236, 0240, 0360, 0171, 0264, 0074, 0233, 0131, 0277, 
  0344, 0030, 0330, 0346, 0024, 0323, 0170, 0354, 0155, 0076, 0317, 0155, 0372, 0270, 0171, 0221, 
  0130, 0336, 0150, 0071, 0345, 0130, 0242, 0227, 0210, 0215, 0327, 0240, 0250, 0116, 0245, 0320, 
  0150, 0215, 0363, 0326, 0356, 0257, 0335, 0044, 0235, 0164, 0066, 0004, 0037, 0027, 0250, 0052, 
  0135, 0231, 0160, 0322, 0131, 0373, 0337, 0313, 0277, 0162, 0270, 0242, 0237, 0000, 0050, 0165, 
  0165, 0141, 0171, 0051, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0156, 0157, 0164, 0151, 0146, 0151, 0143, 0141, 0164, 0151, 0157, 0156, 0055, 0141, 0162, 0145, 
  0141, 0055, 0155, 0145, 0156, 0165, 0056, 0170, 0155, 0154, 0000, 0000, 0000, 0000, 0000, 0000, 
  0351, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 
  0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 0265, 0125, 0362, 0313, 0057, 0311, 0114, 0313, 
  0114, 0116, 0054, 0311, 0314, 0317, 0123, 0160, 0054, 0112, 0115, 0124, 0010, 0050, 0112, 0115, 
  0113, 0055, 0112, 0315, 0113, 0116, 0055, 0126, 0360, 0004, 0052, 0124, 0122, 0110, 0114, 0006, 
  0311, 0332, 0052, 0005, 0127, 0026, 0003, 0371, 0041, 0105, 0211, 0225, 0110, 0152, 0224, 0024, 
  0364, 0355, 0270, 0154, 0010, 0232, 0352, 0221, 0232, 0123, 0200, 0323, 0070, 0220, 0044, 0221, 
  0346, 0070, 0046, 0345, 0227, 0226, 0340, 0064, 0010, 0054, 0013, 0066, 0211, 0013, 0000, 0101, 
  0256, 0122, 0033, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0157, 0162, 0147, 0057, 0000, 0000, 
  0002, 0000, 0000, 0000, 0156, 0141, 0057, 0000, 0003, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0057, 0000, 0000, 0000, 0004, 0000, 0000, 0000, 0141, 0160, 0160, 0154, 0145, 0164, 0057, 0000, 
  0005, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[2069]; const double alignment; void * const ptr;}  na_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\000\001\000\000\000\000\000\050\010\000\000\000"
  "\000\000\000\000\002\000\000\000\004\000\000\000\004\000\000\000"
  "\006\000\000\000\007\000\000\000\010\000\000\000\010\000\000\000"
  "\000\113\055\223\002\000\000\000\000\001\000\000\006\000\114\000"
  "\010\001\000\000\014\001\000\000\350\136\053\125\005\000\000\000"
  "\014\001\000\000\047\000\166\000\070\001\000\000\104\007\000\000"
  "\201\321\040\031\004\000\000\000\104\007\000\000\005\000\114\000"
  "\114\007\000\000\120\007\000\000\341\367\354\015\005\000\000\000"
  "\120\007\000\000\032\000\166\000\160\007\000\000\352\007\000\000"
  "\113\120\220\013\006\000\000\000\352\007\000\000\004\000\114\000"
  "\360\007\000\000\364\007\000\000\063\005\100\241\007\000\000\000"
  "\364\007\000\000\003\000\114\000\370\007\000\000\000\010\000\000"
  "\324\265\002\000\377\377\377\377\000\010\000\000\001\000\114\000"
  "\004\010\000\000\010\010\000\000\265\144\045\040\000\000\000\000"
  "\010\010\000\000\007\000\114\000\020\010\000\000\024\010\000\000"
  "\160\141\156\145\154\057\000\000\007\000\000\000\156\157\164\151"
  "\146\151\143\141\164\151\157\156\055\141\162\145\141\055\160\162"
  "\145\146\145\162\145\156\143\145\163\055\144\151\141\154\157\147"
  "\056\165\151\000\000\000\000\000\336\034\000\000\001\000\000\000"
  "\170\332\325\131\155\163\233\070\020\376\316\257\330\343\123\073"
  "\027\342\330\235\266\067\115\342\216\233\326\251\147\222\064\023"
  "\073\323\311\047\106\200\000\065\102\342\044\141\307\367\353\157"
  "\001\307\057\005\233\340\346\332\353\247\140\330\147\265\373\150"
  "\337\244\234\274\177\110\070\114\251\322\114\212\123\273\173\170"
  "\144\003\025\276\014\230\210\116\355\333\311\320\371\313\176\337"
  "\267\116\376\160\034\070\247\202\052\142\150\000\063\146\142\210"
  "\070\011\050\274\072\354\365\016\273\140\131\011\176\161\122\042"
  "\050\007\007\212\277\116\252\144\112\225\141\124\073\001\043\134"
  "\106\326\231\114\347\212\105\261\201\027\147\057\341\022\041\360"
  "\221\116\051\317\345\054\153\022\063\015\010\212\024\111\000\037"
  "\103\105\051\150\031\232\031\121\364\030\346\062\003\237\010\120"
  "\064\140\332\050\346\145\010\147\006\210\010\072\122\131\011\032"
  "\035\316\363\027\231\010\250\002\023\123\060\124\045\032\144\130"
  "\374\070\277\272\135\370\300\341\072\363\070\363\341\202\371\124"
  "\150\152\021\134\067\177\243\143\364\316\233\027\342\303\174\365"
  "\361\142\165\030\112\324\112\014\262\164\014\024\335\307\005\026"
  "\254\101\317\132\054\260\320\166\000\122\301\013\142\162\203\025"
  "\310\064\007\275\104\053\347\300\321\341\045\356\260\352\360\312"
  "\257\000\230\050\164\306\110\015\076\240\066\164\154\306\070\007"
  "\217\102\246\151\230\361\003\013\045\341\353\150\362\371\313\355"
  "\004\006\127\167\360\165\160\163\063\270\232\334\035\027\073\044"
  "\361\053\222\133\352\141\111\312\131\276\165\104\051\042\314\034"
  "\111\261\056\077\335\234\175\106\371\301\207\321\305\150\162\227"
  "\233\075\034\115\256\076\215\307\060\374\162\003\003\270\036\334"
  "\114\106\147\267\027\203\033\270\276\275\271\376\062\376\164\010"
  "\060\246\271\101\324\332\116\047\204\250\051\221\310\132\100\015"
  "\141\134\243\253\167\270\171\032\115\342\001\304\144\112\161\023"
  "\175\312\246\150\020\001\037\203\342\051\173\304\245\210\312\320"
  "\063\153\274\035\003\013\101\110\163\000\063\305\060\040\214\254"
  "\356\236\265\332\275\003\030\011\377\360\000\136\167\121\204\210"
  "\173\216\074\217\015\012\243\202\041\013\121\371\220\113\251\016"
  "\340\203\324\046\027\277\034\000\034\365\272\335\043\247\373\352"
  "\250\173\000\267\343\001\272\063\310\220\137\365\016\276\112\036"
  "\106\004\355\272\345\236\142\176\154\131\216\203\351\302\004\156"
  "\164\110\174\332\267\000\116\024\375\073\143\212\152\340\314\073"
  "\265\043\163\377\247\275\112\271\074\201\354\116\041\227\047\331"
  "\022\351\360\322\157\307\314\061\002\242\224\117\173\220\353\256"
  "\310\011\222\120\130\317\276\072\241\200\152\137\261\042\024\267"
  "\045\147\075\320\137\146\354\146\266\326\113\223\202\026\135\241"
  "\345\121\132\172\337\250\157\300\347\104\353\123\373\334\334\017"
  "\202\157\231\066\011\025\306\006\026\234\332\144\371\273\153\347"
  "\010\304\054\014\235\103\356\350\251\315\345\214\052\273\377\366"
  "\244\363\370\241\136\056\113\323\134\256\173\164\324\044\071\045"
  "\074\243\166\277\367\246\111\120\033\232\272\114\370\212\026\006"
  "\367\273\115\200\224\104\164\007\340\244\123\362\121\117\315\050"
  "\101\164\311\012\313\037\267\021\062\145\232\171\034\035\230\250"
  "\214\066\131\204\365\323\015\245\237\151\273\077\044\134\067\312"
  "\063\137\012\067\177\264\373\063\046\002\071\163\174\056\277\207"
  "\355\366\343\143\021\135\245\043\230\247\054\144\176\221\211\056"
  "\046\046\161\123\105\103\252\260\345\120\355\226\161\150\077\217"
  "\345\236\124\330\005\334\031\013\114\154\367\137\067\211\033\146"
  "\220\103\060\130\023\064\226\151\202\214\236\332\163\212\253\135"
  "\255\331\014\003\264\031\256\127\066\067\251\305\254\147\377\220"
  "\142\173\236\144\165\111\262\233\112\315\362\365\354\076\326\000"
  "\114\256\106\353\261\106\270\061\313\143\254\044\261\002\360\143"
  "\306\203\362\071\207\163\314\326\130\162\144\250\263\020\350\254"
  "\111\224\322\145\136\013\302\235\342\047\106\232\047\037\354\245"
  "\216\312\106\177\300\257\305\056\227\046\070\033\342\055\343\166"
  "\237\010\250\303\110\305\220\100\122\162\071\315\353\235\117\370"
  "\123\200\072\045\076\316\100\130\026\152\245\353\011\042\376\062"
  "\260\327\034\257\345\052\063\330\135\276\147\154\033\176\017\362"
  "\366\045\260\032\054\115\116\224\036\024\145\301\053\137\174\217"
  "\254\051\342\304\243\274\066\333\334\263\152\175\331\255\353\111"
  "\124\064\320\321\026\032\023\275\057\064\137\065\240\041\311\270"
  "\151\017\136\114\115\172\245\141\347\106\326\126\364\242\255\364"
  "\313\226\322\006\210\103\247\133\114\326\070\062\065\262\275\336"
  "\022\066\225\022\377\036\363\252\171\071\372\200\163\112\260\207"
  "\203\041\016\311\173\300\126\045\267\273\313\255\132\373\067\212"
  "\347\166\002\352\235\337\313\361\075\234\256\016\047\376\275\233"
  "\067\016\273\117\105\360\144\324\222\246\243\172\110\015\105\025"
  "\172\252\005\246\132\134\260\355\122\117\312\373\345\340\120\376"
  "\372\157\313\142\033\130\303\200\261\265\261\304\330\337\261\342"
  "\351\226\333\125\340\312\065\237\251\174\237\053\026\224\354\106"
  "\345\211\313\215\362\067\077\247\342\266\316\317\204\250\210\011"
  "\227\323\020\253\336\233\075\220\305\051\146\077\250\221\351\176"
  "\100\117\142\103\114\132\142\025\156\364\162\374\150\205\364\045"
  "\317\022\261\002\167\173\073\321\265\161\122\037\053\027\145\303"
  "\316\203\045\101\277\212\143\001\116\266\324\055\073\171\235\222"
  "\037\210\233\037\215\235\372\226\315\131\204\145\113\033\242\114"
  "\133\360\216\171\345\222\011\226\144\011\214\220\022\030\043\045"
  "\357\332\052\157\325\130\267\204\233\240\211\024\314\317\253\121"
  "\104\061\312\067\067\111\247\114\354\126\271\255\137\357\356\331"
  "\265\124\141\202\272\304\030\342\307\133\173\304\166\064\146\332"
  "\123\301\133\172\361\226\176\334\076\344\307\110\332\372\204\133"
  "\245\364\047\207\375\076\360\370\161\232\330\007\154\350\203\251"
  "\015\372\336\233\266\252\126\367\072\166\177\355\216\247\065\033"
  "\234\045\236\233\137\102\357\034\323\352\301\042\113\250\142\376"
  "\176\134\154\275\044\372\051\171\324\375\215\363\150\167\353\160"
  "\123\366\100\271\376\035\072\310\366\046\120\372\360\113\042\243"
  "\367\277\212\214\172\047\153\205\027\127\050\371\001\004\215\042"
  "\236\135\075\052\126\056\251\236\240\360\171\264\074\233\131\277"
  "\344\030\330\346\024\323\170\354\155\076\317\155\372\270\171\221"
  "\130\336\150\071\345\130\242\227\210\215\327\240\250\116\245\320"
  "\150\215\363\326\356\257\335\044\235\164\066\004\037\027\250\052"
  "\135\231\160\322\131\373\337\313\277\162\270\242\237\000\050\165"
  "\165\141\171\051\155\141\164\145\057\000\000\000\000\000\000\000"
  "\156\157\164\151\146\151\143\141\164\151\157\156\055\141\162\145"
  "\141\055\155\145\156\165\056\170\155\154\000\000\000\000\000\000"
  "\351\000\000\000\001\000\000\000\170\332\263\311\115\315\053\315"
  "\054\111\315\125\310\113\314\115\265\125\362\313\057\311\114\313"
  "\114\116\054\311\314\317\123\160\054\112\115\124\010\050\112\115"
  "\113\055\112\315\113\116\055\126\360\004\052\124\122\110\114\006"
  "\311\332\052\005\127\026\003\371\041\105\211\225\110\152\224\024"
  "\364\355\270\154\010\232\352\221\232\123\200\323\070\220\044\221"
  "\346\070\046\345\227\226\340\064\010\054\013\066\211\013\000\101"
  "\256\122\033\000\050\165\165\141\171\051\157\162\147\057\000\000"
  "\002\000\000\000\156\141\057\000\003\000\000\000\001\000\000\000"
  "\057\000\000\000\004\000\000\000\141\160\160\154\145\164\057\000"
  "\005\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { na_resource_data.data, sizeof (na_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *na_get_resource (void);
GResource *na_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
